'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var propTypes = require('prop-types');
var auth0 = _interopDefault(require('auth0-js'));
var startsWith = _interopDefault(require('lodash/startsWith'));
var Lockr = _interopDefault(require('lockr'));
var uuid = require('uuid');

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _defineProperty$1(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function resolveUri(uri) {
  return startsWith(uri, '/') ? `${window.location.origin}${uri}` : uri;
}

class Auth0Client {
  constructor(_props) {
    _defineProperty$1(this, "isAuthenticated", () => {
      const currentAuth = Lockr.get(this.props.storageKey);
      return new Date().getTime() < ((currentAuth === null || currentAuth === void 0 ? void 0 : currentAuth.expiresAt) || 0);
    });

    _defineProperty$1(this, "setSession", authResult => {
      var _authResult$idTokenPa;

      const expiresAt = (authResult === null || authResult === void 0 ? void 0 : (_authResult$idTokenPa = authResult.idTokenPayload) === null || _authResult$idTokenPa === void 0 ? void 0 : _authResult$idTokenPa.exp) * 1000;
      Lockr.set(this.props.storageKey, _objectSpread2(_objectSpread2({}, authResult), {}, {
        expiresAt
      }));
    });

    _defineProperty$1(this, "login", props => {
      const nonce = uuid.v4();
      Lockr.set(this.props.nonceKey, nonce);
      this.client.authorize(_objectSpread2({
        nonce,
        state: nonce
      }, props));
    });

    _defineProperty$1(this, "logout", props => {
      Lockr.rm(this.props.storageKey);
      Lockr.rm(this.props.nonceKey);
      this.client.logout(_objectSpread2({
        returnTo: resolveUri(this.props.logoutRedirectUri),
        clientID: this.props.clientID
      }, props));
    });

    _defineProperty$1(this, "authenticate", () => new Promise((resolve, reject) => {
      if (this.isAuthenticated()) return resolve(Lockr.get(this.props.storageKey));
      const nonce = Lockr.get(this.props.nonceKey);
      return this.client.parseHash({
        hash: window.location.hash,
        nonce,
        state: nonce
      }, (err, authResult) => {
        if (authResult && authResult.accessToken && authResult.idToken) {
          this.setSession(authResult);
          resolve(authResult);
        } else {
          reject(err || 'failed to authenticate');
        }
      });
    }));

    _defineProperty$1(this, "renewSession", async () => {
      await this.authenticate().catch(() => ({}));
      return new Promise((resolve, reject) => {
        const authSession = Lockr.get(this.props.storageKey);
        if (!authSession) return resolve(); // We resolve if a renewable session does not exist

        if (this.isAuthenticated()) return resolve(authSession);
        const nonce = Lockr.get(this.props.nonceKey);
        return this.client.checkSession({
          nonce
        }, (err, authResult) => {
          if (authResult && authResult.accessToken && authResult.idToken) {
            this.setSession(authResult);
            resolve(authResult);
          } else {
            Lockr.rm(this.props.storageKey);
            Lockr.rm(this.props.nonceKey);
            reject(err || 'failed to renew session');
          }
        });
      });
    });

    this.props = _objectSpread2({
      redirectUri: '/authorize',
      responseType: 'token id_token',
      scope: 'openid',
      logoutRedirectUri: '/login',
      storageKey: 'auth',
      nonceKey: 'nonce'
    }, _props);
    const {
      domain,
      clientID,
      redirectUri,
      responseType,
      scope,
      audience
    } = this.props;
    this.client = new auth0.WebAuth({
      domain,
      clientID,
      redirectUri: resolveUri(redirectUri),
      responseType,
      scope,
      audience
    });
  }

}

var Context = /*#__PURE__*/React.createContext();

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}
function Auth0Provider(props) {
  const {
    client
  } = props;
  const [authenticated, setAuthenticated] = React.useState(client.isAuthenticated());
  const [error, setError] = React.useState();
  const [authenticating, setAuthenticating] = React.useState(false);

  function logout(logoutProps) {
    setAuthenticated(false);
    client.logout(logoutProps);
  }

  async function authenticate() {
    try {
      setError(undefined);
      setAuthenticating(true);
      await client.authenticate();
      setAuthenticated(client.isAuthenticated());
    } catch (err) {
      setError(err);
    } finally {
      setAuthenticating(false);
    }
  }

  return /*#__PURE__*/React__default.createElement(Context.Provider, _extends({
    value: {
      login: client.login,
      logout,
      authenticate,
      authenticated,
      authenticating,
      error
    }
  }, props));
}
Auth0Provider.propTypes = {
  client: propTypes.instanceOf(Auth0Client).isRequired
};

function useAuth0() {
  return React.useContext(Context);
}

function Login(props = {}) {
  const {
    login
  } = useAuth0();
  React.useEffect(() => {
    login(props);
  }, []);
  return null;
}

function Logout(props = {}) {
  const {
    logout
  } = useAuth0();
  React.useEffect(() => {
    logout(props);
    props.onDidLogout();
  }, []);
  return null;
}
Logout.propTypes = {
  onDidLogout: propTypes.func
};
Logout.defaultProps = {
  onDidLogout() {}

};

function useAuthorize() {
  const {
    authenticate,
    authenticated,
    authenticating,
    error
  } = useAuth0();
  React.useEffect(() => {
    authenticate();
  }, []);
  return [{
    authenticated,
    error
  }, authenticating];
}

function Authorize(props = {}) {
  const [{
    authenticated,
    error
  }, authenticating] = useAuthorize();
  return props.children({
    authenticating,
    authenticated,
    error
  });
}
Authorize.propTypes = {
  children: propTypes.func
};
Authorize.defaultProps = {
  children() {}

};

exports.Authorize = Authorize;
exports.Context = Context;
exports.Login = Login;
exports.Logout = Logout;
exports.Provider = Auth0Provider;
exports.WebClient = Auth0Client;
exports.useAuth0 = useAuth0;
exports.useAuthorize = useAuthorize;
//# sourceMappingURL=index.js.map
